@@ -49,20 +49,36 @@ from gmat.uvlmm.varcom import ai_vmat, ai_mme
 ai_vmat(y, xmat, zmat_lst, gmat_lst, init=None, maxiter=100, cc_par=1e-08)
 ai_mme(y, xmat, zmat_lst, gmat_inv_lst, init=None, maxiter=100, cc_par=1e-08)
 
+from gmat.uvlmm.varcom import fisher_vmat, newton_vmat
+newton_vmat(y, xmat, zmat_lst, gmat_lst, init=None, maxiter=100, cc_par=1e-08)
+fisher_vmat(y, xmat, zmat_lst, gmat_lst, init=None, maxiter=100, cc_par=1e-08)
+
+
+
 from gmat.uvlmm.varcom import weight_emai_vmat, weight_emai_mme
 weight_emai_vmat(y, xmat, zmat_lst, gmat_lst, init=None, maxiter=100, cc_par=1e-08)
 weight_emai_mme(y, xmat, zmat_lst, gmat_inv_lst, init=None, maxiter=100, cc_par=1e-08)
 
+from gmat.uvlmm.varcom import weight_emai_eigen
+
+
+from gmat.uvlmm.varcom import weight_emnewton_vmat
+weight_emnewton_vmat(y, xmat, zmat_lst, gmat_lst, init=None, maxiter=100, cc_par=1e-08)
+
+from gmat.uvlmm.varcom import weight_emfisher_vmat
+weight_emfisher_vmat(y, xmat, zmat_lst, gmat_lst, init=None, maxiter=100, cc_par=1e-08)
+
 
 from gmat.uvlmm.varcom import weight_pxemai_vmat, weight_pxemai_mme
 zmat_lst = [zmat, zmat, zmat, zmat, zmat]
 gmat_lst = [a[0], b[0], a[0]*a[0], a[0]*b[0], b[0]*b[0]]
-weight_pxemai_vmat(y, xmat, zmat_lst, gmat_lst, init=None, maxiter=100, cc_par=1e-08)
+weight_pxemai_vmat(y, xmat, zmat_lst, gmat_lst, init=None, maxiter=100, cc_par=1e-08, step=1)
 weight_pxemai_mme(y, xmat, zmat_lst, gmat_inv_lst, init=None, maxiter=100, cc_par=1e-08)
 
 
 
 
+
 # Estimate the variances
 from gmat.uvlmm.uvlmm_varcom import _wemai_multi_gmat
 gmat_lst = [a[0], b[0]]
